# frozen_string_literal: true

module BucketCake
  class Decoder
    def initialize(files, klass)
      @files = files
      @klass = klass
    end

    def items
      Enumerator.new do |y|
        files.each do |gzdata|
          unpack(gzdata) do |element|
            y << klass.decode(element)
          end
        end
      end
    end

    private

    attr_reader :files, :klass

    def unpack(gzdata)
      Zlib::GzipReader.new(gzdata).each_line.each do |line|
        line.strip!
        next if line.empty?

        yield Base64.decode64(line)
      end
    end
  end
end
